/**
* Copyright (c) 2009, Marc 'Foddex' Oude Kotte <foddex@foddex.net>
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in the
*       documentation and/or other materials provided with the distribution.
*     * Neither the name of Marc 'Foddex' Oude Kotte nor the
*       names of its contributors may be used to endorse or promote products
*       derived from this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY Marc 'Foddex' Oude Kotte ''AS IS'' AND ANY
* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL Marc 'Foddex' Oude Kotte BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include <string.h>

struct user {
	int				Id;
	string			Username;
	string			Email;
	size_t			BirthdayTimestamp;

	user() {}
	user( int id, const string& username, const string& email, size_t bt )
	:	Id( id )
	,	Username( username )
	,	Email( email )
	,	BirthdayTimestamp( bt ) {
	}

	json::json_object* write_json() const {
		json::serializer s;
		s.set( "id", Id );
		s.set( "username", Username );
		s.set( "email", Email );
		s.set( "birthday_timestamp", BirthdayTimestamp );
		return s.get_object();
	}
	void read_json( const json::json_object* object ) {
		json::serializer s( object );
		s.get( "id", Id );
		s.get( "username", Username );
		s.get( "email", Email );
		s.get( "birthday_timestamp", BirthdayTimestamp );
	}
};

struct group {
	int				Id;
	vector<user>	Users;

	group() {}
	group( int id ) 
	:	Id( id ) {
	}

	json::json_object* write_json() const {
		json::serializer s;
		s.set( "id", static_cast<__int64>( Id ) );
		s.set( "users", Users );
		return s.get_object();
	}
	void read_json( const json::json_object* object ) {
		json::serializer s( object );
		s.get( "id", Id );
		s.get( "users", Users );
	}
};

bool operator==( const user& lhs, const user& rhs ) {
	return
		lhs.Id==rhs.Id &&
		lhs.Username==rhs.Username &&
		lhs.Email==rhs.Email &&
		lhs.BirthdayTimestamp==rhs.BirthdayTimestamp;
}

bool operator==( const group& lhs, const group& rhs ) {
	return 
		lhs.Id==rhs.Id && 
		lhs.Users==rhs.Users;
}

